@@ -1,13 +1,15 @@
+"""fmdpy"""
 import base64
-VERSION="0.2.2"
+
+VERSION = "0.2.4"
 headers = {
     'User-Agent': 'Mozilla/5.0 (Windows NT 6.1; WOW64; rv:39.0) Gecko/20100101 Firefox/75.0',
 }
 
-art='''  _| |_ |  \ /  |   /\  (   _   ) || || |
+ART = r'''  _| |_ |  \ /  |   /\  (   _   ) || || |
  /     \|   v   |  /  \  | | | || \| |/ |
 ( (| |) ) |\_/| | / /\ \ | | | | \_   _/
  \_   _/| |   | |/ /__\ \| | | |   | |
    |_|  |_|   |_/________\_| |_|   |_|
                                          '''
-mnc=base64.decodebytes
+mnc = base64.decodebytes
