@@ -1,7 +1,13 @@
+"""song class for fmdpy."""
 from dataclasses import dataclass
 
+# needed to store metadata
+#pylint: disable=too-many-instance-attributes
+
+
 @dataclass
 class Song:
+    """Song class to hold metadata."""
     songid: str
     title: str = "Unknown"
     album: str = "Unknown"
@@ -11,7 +17,3 @@ class Song:
     url: str = ""
     thumb_url: str = ""
     raw_json = {}
-
-    def geturl(self):
-        pass
-
